function [AD]=AerodynamicDerivatives(vred,varargin)
%% Description
% This routine calculates the values of the aerodynamic derivatives at
% selcted reduced velocities vred. It returns a matrix AD[18xNvred]
% Ole Andre iseth 05.11.2014
%% Define input
p=inputParser;
addParameter(p,'PlotAD','No',@ischar);                  %Plot the aerodynamic derivatives
addParameter(p,'ADType','Theodorsen',@ischar);          %Aerodynamic derivatives type
addParameter(p,'RAD',[],@isnumeric);                    %Aerodynamic derivatives type
addParameter(p,'d',[],@isnumeric);                    %Aerodynamic derivatives type
parse(p,varargin{:})
AD=[];
%% Theodorsen
%Calculate the values of the aerodynamic derivaties
if strcmp(p.Results.ADType,'Theodorsen')
    AD=zeros(18,length(vred));
    for n=1:length(vred)
        if vred(1,n)==0
            F=0;G=0;
            AD(10,n)=pi/2;
        else
            pos=0.5/vred(1,n);
            J0=besselj(0,pos);J1=besselj(1,pos);
            Y0=bessely(0,pos);Y1=bessely(1,pos);
            a=J1+Y0;b=Y1-J0;c=a^2+b^2;
            F=(J1*a+Y1*b)/c; G=-(J1*J0+Y1*Y0)/c;
            AD(:,n)=[0;
                0;
                0;
                0;
                0;
                0;
                -2*pi*F*vred(1,n);
                pi/2*(1+F+4*G*vred(1,n))*vred(1,n);
                2*pi*(F*vred(1,n)-G/4)*vred(1,n);
                pi/2*(1+4*G*vred(1,n));
                0;
                0;
                -pi/2*F*vred(1,n);
                -pi/8*(1-F-4*G*vred(1,n))*vred(1,n);
                pi/2*(F*vred(1,n)-G/4)*vred(1,n);
                pi/2*G*vred(1,n);
                0;
                0];
        end
    end
end
%% Data calulated by the function mvregress
if strcmp(p.Results.ADType,'mvregress')
    AD=zeros(18,length(vred));
    for n=1:length(vred)
        BETA=p.Results.RAD;
        Br = [BETA(1:size(AD,1))';BETA(size(AD,1)+1:2*size(AD,1))'; BETA(2*size(AD,1)+1:end)'];
        AD(:,n)=([1,vred(1,n), vred(1,n)^2]*Br)';
    end
end
%% Data calculated by simple polynominal fit
if strcmp(p.Results.ADType,'poly')
    AD=zeros(18,length(vred));
    for n=1:length(vred)
        RAD=p.Results.RAD;
        AD(:,n)=RAD(:,1)*vred(1,n)^3+RAD(:,2)*vred(1,n)^2+RAD(:,3)*vred(1,n)+RAD(:,4);
    end
end
%% Data calculated by rational function
if strcmp(p.Results.ADType,'RationalFunctions')
    AD=zeros(18,length(vred));
    if size(p.Results.RAD,2)>1
        d=p.Results.d;
        RFa=p.Results.RAD;
        aa=[];
        for m=1:3
            for n=1:3
                aa=[aa; squeeze(RFa(m,n,:))];
            end
        end    
    AD=zeros(18,length(vred));
    posAD=[1 5 2   11 7 8  17 13 14;   4 6 3    12 10 9   18 16 15];
    [Cp]=CmatrixRationalFunctionsWindLoad(vred,d);
    tmp=Cp*aa;
    tmp=vec2mat(tmp,length(vred));
    AD(posAD(2,:),:)=tmp(1:2:18,:);
    AD(posAD(1,:),:)=tmp(2:2:18,:);
    elseif size(p.Results.RAD,3)==1
        d=p.Results.d;
        aa=p.Results.RAD;
        AD=zeros(18,length(vred));
        posAD=[1 5 2   11 7 8  17 13 14;   4 6 3    12 10 9   18 16 15];
        [Cp]=CmatrixRationalFunctionsWindLoad(vred,d);
        tmp=Cp*aa;
        tmp=vec2mat(tmp,length(vred));
        AD(posAD(2,:),:)=tmp(1:2:18,:);
        AD(posAD(1,:),:)=tmp(2:2:18,:);
        
    end
end
%% Plot the resulting aerodynamic derivatives if this option is selected
if strcmp(p.Results.PlotAD, 'No')==0
    plotAerodynamicDerivatives(vred,AD)
end