function [std]=getDynamicResponse(datfile,modeNumber)


%HORIZONTAL MODES, Y-DIRECTION(u-wind)
%%
% datfile = 'parametricd07t01g03.dat'
% modeNumber=3;
[phi,w_n]=getPhi(datfile,modeNumber);
M_modal=getModalMass(datfile,modeNumber);
Phi = phi(1,:);

zeta=0.002;                          %Denne m velges
% w_n=0.20279; %[rad/s]                %Denne m hentes fra ABAQUS
% M_modal=3.64485e7; %[kg]             %Denne m hentes fra ABAQUS
C_modal=2*zeta*w_n*M_modal;
K_modal=w_n^2*M_modal;

%% The mode shape,                     denne hentes fra ABAQUS
L=2800;
y=linspace(0,L,139);
% Phi=zeros(1,length(y));
% nn=1;                                 
% for k=1:length(y)
%     Phi(1,k)=sin(nn*pi*y(1,k)/L);
% end
% figure; hold on; grid on;
% plot(y,Phi)
% xlabel('x');
% ylabel('\Phi(x)');



%% 
B=30; %[m]
D=2.5; %[m] 

CLs=-0.15;                      %s angir strek
CDs=1.2;
CMs=0.3;

CLm=6.3;                        %m angir merket, alts derivert
CDm=0;
CMm=1.0;


rho=1.25; %[kg/m^3]
V_u=45.7; %[m/s]                 

%Calculating sigma, from NS EN 1991-1-4,4.4

k_1=1.0;                        %turbulence factor, uses recommended value
c_0=1.0;                        %terrain factor
z=70.8;                         %explained in the report, under static wind load
z_0=0.01;                       %roughness factor, explained in the report
Iu=k_1/(c_0* log(z/z_0));       %tubulence intencity, u-direction(y)
Iw=0.5*Iu;                      %tubulence intencity, w-direction(z)
sigma_u=V_u*Iu;
%N400- Bridge Design:2.5.2.1
L_1=100;                        %Reference length-scale [m]
z_1=10;                         %Reference height [m]
xLu=L_1*(z/z_1)^0.3;            %Integral length scale[m]

%% Calc. u- and w- spectra:
Au=6.8; %N400
omegaaxis=logspace(-2,1,1000); %creating omega values from 0.01 to 10 [rad/s].

Su=zeros(1,length(omegaaxis));
for k=1:length(omegaaxis)
    Su(1,k)=(sigma_u)^2*Au*xLu/(2*pi*V_u)/((1+1.5*Au*omegaaxis(1,k)*xLu/(2*pi*V_u))^(5/3));
end

figure;
plot(omegaaxis,Su);grid on;
xlabel('$\omega$','Interpreter','latex','FontSize',18);
ylabel('$S_{u}(\omega)$','Interpreter','latex','FontSize',18);
xlim([0 1]);


% Evaluate the double integral
SQ_u=zeros(1,length(omegaaxis));


C_uz=10;                        %Usikker p denne, se N400 side 90.
for k=1:length(omegaaxis)
    Int=zeros(length(y),length(y));
    for m=1:length(y)
        for n=1:length(y)
            dx=abs(y(1,n)-y(1,m));
            Su1u2=Su(1,k)*exp(-C_uz*omegaaxis(1,k)*dx/(V_u*2*pi));
            Int(m,n)=(0.5*rho*V_u*(2*D*CDs))^2*Phi(1,m)*Su1u2*Phi(1,n);            
        end
    end
    SQ_u(1,k)=trapz(y,trapz(y,Int));
end

%% Plot generalized buffeting load

figure; hold on; grid on;
plot(omegaaxis,SQ_u);
xlim([0 1]);
%set(gca,'YScale','log'); 
xlabel('$\omega$','Interpreter','latex','FontSize',18);
ylabel('$S_{\tilde{Qu}_{b}}(\omega)$','Interpreter','latex','FontSize',18);


%% The response spectrum
x=L/2;                      %where to extract value
Phi_x=sin(pi*x/L);

C_ae_u_int=-0.5*rho*V_u*Phi.^2*(2*D*CDs);
C_ae_u=trapz(y,C_ae_u_int);
K_ae_u=0;

H_u_modal=(-omegaaxis.^2*M_modal + i*omegaaxis*(C_modal-C_ae_u)+(K_modal-K_ae_u)).^-1;
H_u_modal_conj=conj(H_u_modal);
S_ry_u=Phi_x*H_u_modal_conj.*H_u_modal.*SQ_u*Phi_x;

figure()
plot(omegaaxis,abs(H_u_modal));grid on;
xlabel('$\omega$','Interpreter','latex','FontSize',18);
ylabel('$|H_u(\omega)|$','Interpreter','latex','FontSize',18);
xlim([0 1]);

figure()
plot(omegaaxis,(S_ry_u));grid on;
xlim([0 1]);
%set(gca,'YScale','log'); 
xlabel('$\omega$','Interpreter','latex','FontSize',18);
ylabel('$S_{\tilde{r}_{y}}(\omega)$','Interpreter','latex','FontSize',18);

%% The standard deviation of the response

sigma_ry=sqrt(trapz(omegaaxis,(S_ry_u)));
%%This holds due to a zero mean for the response
%%NOTE: Su is defined in the standard as onesided-> don't multiply with two

end